## 0.3.13 (2026-03-08)

### Feat

- **llm**: add model override parameter to get_llm()

## 0.3.12 (2026-02-26)

### Fix

- **tracing**: forward **kwargs in trace_agent_stream decorator (#32)

## 0.3.11 (2026-02-24)

### Fix

- **tracing**: suppress OTel context-detach ERROR logs in async generators (#31)

## 0.3.10 (2026-02-18)

### Fix

- **tracing**: silence OTel context detach error in async generators (#30)

## 0.3.9 (2025-12-08)

### Feat

- synchronize agent base classes with ai-platform-engineering
- **middleware**: add custom deepagents middleware

### Fix

- **lint**: fix linting

## 0.3.6 (2025-11-10)

### Feat

- agent base classes (#26)

### Fix

- OpenAI default_headers config option

## 0.3.3 (2025-10-07)

### Feat

- add extended thinking support for AWS Bedrock, Anthropic, and Vertex AI Claude 4+ models

## 0.3.2 (2025-10-02)

### Fix

- **Makefile**: use folder name cnoe_agent_utils

## 0.3.1 (2025-09-30)

### Feat

- make streaming option configurable for AWS bedrock models

### Fix

- lint errors
- lint errors
- **conventional-commits**: add bump, release

### Refactor

- **aws-bedrock**: simplify prompt caching implementation

## 0.3.0 (2025-08-17)

### Feat

- Add OpenAI config options
- add gpt-5 and streaming support

### Fix

- update README.md
- uv sync
- updates
- revert pyproject.toml to 0.2.2
- use uv in .cz.toml
- **pyproject.toml**: remove all package and update default dependency
- updates
- updates
- updates
- update new GHA tests
- add coverage as comment
- unit tests gha
- update gcp creds for example run
- unit tests
- update GHA
- update GHA
- updates
- lint
- updates
- 'LLMFactory' object has no attribute 'provider'

### Refactor

- add unit tests and examples

## 0.2.2 (2025-08-07)

### Fix

- release 0.2.2

## 0.2.1 (2025-08-07)

### Fix

- remove the unused is_generic_processing_message
- trace input does not match the user input
- silence unwanted logs llmfactory
- docs
- update docs

## 0.1.5 (2025-07-23)

### Feat

- **tracing**: add package for tracing

## 0.1.4 (2025-06-03)

### Fix

- **aws**: accept IAM AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY

## 0.1.3 (2025-06-03)

### Fix

- bump 0.1.3
- update changelog

## 0.1.2 (2025-06-03)

### Fix

- update README.md
- sign-off
- changelog

## 0.1.1 (2025-06-03)

### Fix

- bump 0.1.1
- **examples**: update examples

## 0.1.0 (2025-06-02)

### Fix

- update pyproject.toml
